//	Program: gui
//
//	File:	gui_main.h
//	Author:	Scott McLean
//	Date:	July 11, 1996
//
//	Purpose:
//		When called from the Terminal this program passes a 
//		message to the Browser to open the files specified 
//		on the command line.  
//
//	Usage:	gui_launcher myDir myFile.txt
//				Would cause the browser to open the folder myDir
//				and open the file myFile.txt in it's default 
//				application.
//

#ifndef GUI_MAIN_H
#include "gui_main.h"
#endif

#include <stdio.h>

//
//	Application Constructor.  Sets messenger to the Browser
//		and starts creating the message.
//
LauncherApp::LauncherApp():BApplication('gui1')
{
	browserMessenger = new BMessenger('SHRK') ;
	browserMessage = new BMessage('Bopn') ;
}

//
//	ArgvReceived. Takes the arguments off the command line,
//		converts them to record_refs and adds the ref to the
//		message.  When all the arguments have been parsed,
//		the message is sent to the browser.  If an invalid
//		argument is sent an error message is printed.
//
void LauncherApp::ArgvReceived(int argc, char **argv)
{
	int i = 1 ;
	while(argc > 1)
	{
		if (get_ref_for_path(argv[i], &ref) != B_ERROR)
		{
			browserMessage->AddRef("refs", ref) ;
			if (!does_ref_conform(ref, "FSItem"))
				printf("  '%s' not a FSItem.\n",argv[i]) ;
			i++ ;
			argc-- ;
		}
		else
		{
			printf("  '%s' not found.\n",argv[i]) ;
			i++ ;
			argc-- ;
		}

	}
	browserMessenger->SendMessage(browserMessage) ;
	delete browserMessage ;
	browserMessenger->~BMessenger() ;
	
	
}

//
//	main.	Initializes the BApp, posts the message to quit, 
//		which is recieved after the arguments, and calls Run().
//
main() 
{
	LauncherApp *gui_app ;
	gui_app = new LauncherApp() ;
	
	gui_app->PostMessage(B_QUIT_REQUESTED) ;	
	gui_app->Run() ;
	
	delete(gui_app) ;
	return(TRUE) ;
}